﻿if (typeof WasLite === "undefined") {

    

    /**
     * WasLiteLite js layer core class.
     */
    WasLite = {
        _constructors: [] ,
        _eventListenerList:{}
        
    };    
    /**
     * List of resource files loaded by WasLite.
     * 用来确保插件js不会被多次加载，相关的方法应该在插件js class里面使用。
     */
    WasLite.resources = {base: true};
    
    WasLite.hasResource = function(name) {
        return WasLite.resources[name];
    };
    
    WasLite.addResource = function(name) {
        WasLite.resources[name] = true;
    };

    WasLite.onLoad = function() {
        //兼容IDE环境用，不用做任何事情。
    };
    
    /**
     * 添加插件，由插件js class来调用。
     * @param {Function} 插件初始化函数
     */
    WasLite.addPlugin = function(func) {
        func();
    };
    
    //给自己用的纪录日志方法，应用和插件中，应该调用console.log
    WasLite.log = function(msg){
        console.log(msg);
    }
    
    // init callbacks
    WasLite.callbackID = 0;
    WasLite.callbacks = {};

    /** 
     * 调用Native层插件对象的一个方法，给基础能力用
     *   plugin:插件名称
     *   method:插件方法
     *     args:执行参数，为关联数组。目前只支持字符串值
     * resultCB:执行结果回调函数
     *  errorCB:执行出错回调函数
     */
    WasLite.exec = function(plugin,method,args,resultCB,errorCB) { 
        //alert('in WasLite.exec');
        WasLite.execA(plugin,method,args,resultCB,errorCB,"");
    };
    
    /** 
     * 调用Native层插件对象的一个方法，业务能力用。
     *   plugin:插件名称
     *   method:插件方法
     *     args:执行参数，为关联数组。目前只支持字符串值
     * resultCB:执行结果回调函数
     *  errorCB:执行出错回调函数
     *  ability:业务能力代码
     */
    WasLite.execA = function(plugin,method,args,resultCB,errorCB,ability) { 
        //alert('in WasLite.execA');
        // 分配callbackID
        var callbackID = plugin + WasLite.callbackID++;

        // 保存回调函数
        if (resultCB || errorCB) {
            WasLite.callbacks[callbackID] = {success:resultCB, fail:errorCB};
        }

        //构造参数字符串
        var argsStr = "";
        var split1=String.fromCharCode(1);
        var split2=String.fromCharCode(2);
        
        for (var key in args) {
            var value = args[key];
            argsStr = argsStr + split1 + key + split2 + value;
        }
        //通过__js2java_proxy来调用到Native层
        __js2java_proxy__lite.dispatch(plugin,method,argsStr,callbackID,ability);
        //alert('WasLite.execA end.');
    };

    /**
     * Native层用来回调插件方法执行结果的函数
     */
    WasLite.callbackResult = function(callbackID, args, keepCallback) {
        //alert('callbackResult('+callbackID+')');
        if (WasLite.callbacks[callbackID]) {
            var callback = WasLite.callbacks[callbackID];
            if(keepCallback && keepCallback==1){
                //alert('keep callback');
            }
            else{
                delete WasLite.callbacks[callbackID];
            }
            if (callback.success) {
               //alert('callback_success');
               callback.success(args);
           }
        }
    };
    
    /**
     * Native层用来回调插件方法执行结果的函数
     */
    WasLite.callbackError = function(callbackID, errorCode,errorMsg) {

        if (WasLite.callbacks[callbackID]) {
            var callback = WasLite.callbacks[callbackID];
            delete WasLite.callbacks[callbackID];
            if (callback.fail) {
                callback.fail(errorCode,errorMsg,arguments[3]);
            }
        }
    };

    /**
     * Native层用来发布事件的方法
     */
    WasLite.fireEvent = function(type, id ,data) {
        //alert('WasLite.fireEvent('+type+','+id+','+data+')');
        //alert(WasLite._eventListenerList[type]);
        var parentNeedProcess ;
        
        if(WasLite._eventListenerList[type]){
            if(type=="onCreate" || type=="onResume"){
                var eventData = {};
                eventData["startType"] = data["__startType"];
                eventData["netState"] = data["__netState"];
                if(data["__command"]){
                    eventData["command"] = data["__command"];
                    delete data["__command"];
                }
                delete data["__startType"];
                delete data["__netState"];
                eventData["callArgs"] = data;
                WasLite._eventListenerList[type](eventData,type,id); 
            }
            else if(type=="devicemotion")
            {
                eval("var acc ="+data["acceleration"]+";");
                data["acceleration"]=acc;
                WasLite._eventListenerList[type](data,type,id); 
            }
            else if(type=="onBack")
            {
            	try
            	{
            		parentNeedProcess = WasLite._eventListenerList[type](data,type,id); 
            	}
            	catch(e)
            	{
            		console.log(e.message);
            		parentNeedProcess=true;
            	}
            }
            else{
                WasLite._eventListenerList[type](data,type,id); 
            }
        }
        if(id && id!=-1){
        
        	if(parentNeedProcess === false)
        	{
        		__js2java_proxy.notifyEventResult(id,false);
        	}
        	else
        	{
        	 	__js2java_proxy.notifyEventResult(id,true);
        	}           
            //setTimeout(function(){__js2java_proxy.notifyEventResult(id);}, 1000);
        }
    };
    
    /**
     * 应用用来注册事件监听的方法
     * @param eventName,需要监听的事件名称
     * @param eventCB,回调函数
     */
    WasLite.addEventListener = function(eventName, eventCB) {
        //alert('WasLite.addEventListener('+eventName+')');
        WasLite._eventListenerList[eventName] = eventCB;
    };

    WasLite.removeEventListener = function(eventName) {
        delete WasLite.callbacks[eventName];
    };
    
    //注册4个默认事件处理器，用于调试，发布时这些代码应该注释掉。
    function _default_onCreate(eventName,eventID,eventData){
        //调试代码放这边
    }
    WasLite.addEventListener("onCreate",_default_onCreate); 
    
    function _default_onPause(eventName,eventID,eventData){
        //调试代码放这边
    }
    WasLite.addEventListener("onPause",_default_onPause);   
    
    function _default_onResume(eventName,eventID,eventData){
        //调试代码放这边
    }
    WasLite.addEventListener("onResume",_default_onResume);    
    
    function _default_onExit(eventName,eventID,eventData){
        //调试代码放这边
        //alert('hold住，不退出！');
    }
    WasLite.addEventListener("onExit",_default_onExit);  
    
};
